import { storageLocal } from './storage';
import { useUserStoreWithOut } from '@/stores/modules/user';

const StorageKey = {
  USER_INFO_KEY: 'USER__INFO__',
  USER_DETAIL_KEY: 'USER_DETAIL_KEY',
  MatchMakingIdentity_KEY: 'MatchMakingIdentity_KEY',
  LocationCity_KEY: 'LocationCity_KEY',
  VirtualUserId_KEY: 'VirtualUserId_KEY',
};

export function getToken() {
  return useUserStoreWithOut().token;
}

export function getRefreshToken() {
  return useUserStoreWithOut().refreshToken;
}

export function getUserInfo() {
  return storageLocal.getItem<API.IdentityModelTokenCacheItem>(StorageKey.USER_INFO_KEY);
}

export function setUserInfo(userInfo: API.IdentityModelTokenCacheItem) {
  return storageLocal.setItem(StorageKey.USER_INFO_KEY, userInfo);
}

export function removeUserInfo() {
  return storageLocal.removeItem(StorageKey.USER_INFO_KEY);
}

export function getUserDetail() {
  return storageLocal.getItem<API.UserInfoV2>(StorageKey.USER_DETAIL_KEY);
}

export function setUserDetail(userDetail: API.UserInfoV2) {
  return storageLocal.setItem(StorageKey.USER_DETAIL_KEY, userDetail);
}

export function removeUserDetail() {
  return storageLocal.removeItem(StorageKey.USER_DETAIL_KEY);
}

export type LoginVirtualRes = {
  virtualUserId: string;
  virtualPhoneNumber: string;
};

export function getStorageVirtualUserId() {
  return storageLocal.getItem<LoginVirtualRes>(StorageKey.VirtualUserId_KEY);
}

export function setStorageVirtualUserId(res: LoginVirtualRes) {
  return storageLocal.setItem(StorageKey.VirtualUserId_KEY, res);
}

export function removeStorageVirtualUserId() {
  return storageLocal.removeItem(StorageKey.VirtualUserId_KEY);
}

type StorageLocation = {
  city: string;
  province: string;
};

export function getStorageLocationCity() {
  return storageLocal.getItem<StorageLocation>(StorageKey.LocationCity_KEY);
}

export function setStorageLocationCity(location: StorageLocation) {
  return storageLocal.setItem(StorageKey.LocationCity_KEY, location);
}

export function removeStorageLocationCity() {
  return storageLocal.removeItem(StorageKey.LocationCity_KEY);
}
